@@ -1,6 +1,5 @@
 
 from pathlib import Path
-from typing import cast
 
 from unittest.mock import MagicMock, patch
 from dataclasses import dataclass
@@ -71,7 +70,7 @@ class TestClient(TestCase):
 
     @patch("jsonapi_client.client.request")
     def test_get_no_meta(self, test_request: MagicMock) -> None:
-        client: JsonAPIClient[Movie] = JsonAPIClient(url="http://example.com/api", schema=Movie, auth=None)
+        client: JsonAPIClient = JsonAPIClient(url="http://example.com/api", schema=Movie, auth=None)
         fixture = Path("tests/fixtures/movie.json")
         response = Response()
         response.status_code = 200
@@ -79,7 +78,6 @@ class TestClient(TestCase):
         test_request.return_value = response
 
         result, meta = client.get()
-        result = cast("Movie", result)
 
         self.assertEqual(meta, {})
         self.assertEqual(result.title, "Funny Games")
